<?xml version="1.0" ?><!DOCTYPE TS><TS language="uk" version="2.0">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <source>Version %1</source>
        <translation>Версія %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 - вільне програмне забезпечення, проте його розвиток займає дорогоцінний час.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Будь-ласка, &lt;a href=&apos;%1&apos;&gt;пожертвуйте&lt;/a&gt; для підтримки подальшого розвитку %2.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Випущено під &lt;a href=&apos;%1&apos;&gt;ліцензією GNU General Public License&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Закрити</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Про програму</translation>
    </message>
    <message>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>Те, що ви завжди хотіли знати про %1 і ніколи не наважувались запитати</translation>
    </message>
    <message>
        <source>You may want to try my other apps as well:</source>
        <translation>Спробуйте також:</translation>
    </message>
    <message>
        <source>%1, a YouTube app</source>
        <translation>%1, застосунок YouTube</translation>
    </message>
    <message>
        <source>%1, a YouTube music player</source>
        <translation>%1, музичний програвач для YouTube</translation>
    </message>
    <message>
        <source>Translate %1 to your native language using %2</source>
        <translation>Перекласти %1 на вашу рідну мову використовуючи %2</translation>
    </message>
    <message>
        <source>Licensed to: %1</source>
        <translation>Ліцензія належить: %1</translation>
    </message>
</context>
<context>
    <name>ActivationDialog</name>
    <message>
        <source>Enter your License Details</source>
        <translation>Введіть дані вашої ліцензії</translation>
    </message>
    <message>
        <source>&amp;Email:</source>
        <translation>&amp;Email:</translation>
    </message>
    <message>
        <source>&amp;Code:</source>
        <translation>&amp;Код:</translation>
    </message>
</context>
<context>
    <name>ActivationView</name>
    <message>
        <source>Please license %1</source>
        <translation>Ліцензуйте %1</translation>
    </message>
    <message>
        <source>This demo has expired.</source>
        <translation>Пробний період вичерпано.</translation>
    </message>
    <message>
        <source>Without a license, the application will expire in %1 days.</source>
        <translation>Програма буде заблокована через %1 днів, якщо ви не купите ліцензію.</translation>
    </message>
    <message>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>Купуючи повну версію, Ви також подякуєте за зусилля, які я вклав в створення %1.</translation>
    </message>
    <message>
        <source>Use Demo</source>
        <translation>Демонстрація</translation>
    </message>
    <message>
        <source>Enter License</source>
        <translation>Ввести ліцензію</translation>
    </message>
    <message>
        <source>Buy License</source>
        <translation>Купити ліцензію</translation>
    </message>
    <message>
        <source>The full version allows you to add more than %1 tracks to the playlist and listen to your music without interruptions.</source>
        <translation>Повна версія дозволяє додавати більше %1 пісень до плейлістів та слухати вашу музику без переривань.</translation>
    </message>
</context>
<context>
    <name>AlbumInfo</name>
    <message>
        <source>Buy on %1</source>
        <translation>Придбати на %1</translation>
    </message>
    <message>
        <source>Read more</source>
        <translation>Детальніше</translation>
    </message>
</context>
<context>
    <name>AlbumListView</name>
    <message>
        <source>Artist</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Year</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Popularity</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reversed Order</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sort by</source>
        <translation>Сортувати по</translation>
    </message>
</context>
<context>
    <name>ArtistInfo</name>
    <message>
        <source>Read more</source>
        <translation>Детальніше</translation>
    </message>
</context>
<context>
    <name>ArtistListView</name>
    <message>
        <source>Track Count</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Album Count</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Name</source>
        <translation>Назва</translation>
    </message>
    <message>
        <source>Year</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Popularity</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reversed Order</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sort by</source>
        <translation>Сортувати по</translation>
    </message>
</context>
<context>
    <name>BreadcrumbWidget</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Назад</translation>
    </message>
    <message>
        <source>Go back</source>
        <translation>Повернутись</translation>
    </message>
</context>
<context>
    <name>ChooseFolderView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Ласкаво просимо до &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>%1 needs to scan your music collection.</source>
        <translation>%1 необхідно просканувати вашу музичну колекцію.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>Use iTunes collection</source>
        <translation>Використовувати колекцію ITunes</translation>
    </message>
    <message>
        <source>Use %1</source>
        <translation>Використати %1</translation>
    </message>
    <message>
        <source>Choose a folder...</source>
        <translation>Виберіть теку...</translation>
    </message>
    <message>
        <source>%1 will connect to the Last.fm web services and pass artist names and album titles in order to fetch covert art, biographies and much more.</source>
        <translation>%1 під’єднається до Last.fm і передасть інформацію про імена виконавців та назви альбомів, щоб отримати обкладинки дисків, біографію та інше.</translation>
    </message>
    <message>
        <source>If you have privacy concerns about this you can quit now.</source>
        <translation>Якщо вас турбує питання приватності щодо цього ви можете вийти зараз.</translation>
    </message>
    <message>
        <source>Where&apos;s your music collection?</source>
        <translation>Де ваша музична колекція?</translation>
    </message>
    <message>
        <source>Select the location of your music collection.</source>
        <translation>Виберіть місце розташування вашої музичної колекції.</translation>
    </message>
    <message>
        <source>Locate your collection</source>
        <translation>Розмістіть вашу колекцію</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Очистити</translation>
    </message>
</context>
<context>
    <name>CollectionScanner</name>
    <message>
        <source>A scanning task is already running</source>
        <translation>Процес сканування вже запущено</translation>
    </message>
</context>
<context>
    <name>CollectionScannerView</name>
    <message>
        <source>%1 is scanning your music collection.</source>
        <translation>%1 сканує вашу музичну колекцію.</translation>
    </message>
    <message>
        <source>%1 is using &lt;a href=&apos;%2&apos;&gt;%3&lt;/a&gt; to catalog your music.</source>
        <translation>%1 використовує &lt;a href=&apos;%2&apos;&gt;%3&lt;/a&gt; для впорядкування вашої музики.</translation>
    </message>
    <message>
        <source>This will take time depending on your collection size and network speed.</source>
        <translation>Це займе деякий час, залежно від розміру вашої колекції та швидкості мережі.</translation>
    </message>
    <message>
        <source>Go grab a coffee</source>
        <translation>Можете поки випити кави</translation>
    </message>
</context>
<context>
    <name>DownloadWidget</name>
    <message>
        <source>Downloading update...</source>
        <translation>Завантажую оновлення ...</translation>
    </message>
</context>
<context>
    <name>DropArea</name>
    <message>
        <source>Drop here to append to the playlist</source>
        <translation>Перетягніть сюди, щоб додати до списку відтворення</translation>
    </message>
</context>
<context>
    <name>FinderWidget</name>
    <message>
        <source>Artists</source>
        <translation>Виконавці</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>Альбоми</translation>
    </message>
    <message>
        <source>Folders</source>
        <translation>Теки</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>Грати</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Пауза</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Грати/Пауза</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Зупинити</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>Зупинити програвання після цього треку</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>Наступний трек</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>Попередній трек</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>Збільшення гучності</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>Зменшення гучності</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Вимкнути звук</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>Прокрутити вперед</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>Прокрутити назад</translation>
    </message>
</context>
<context>
    <name>LastFm</name>
    <message>
        <source>Authentication failed</source>
        <translation>Помилка аутентифікації</translation>
    </message>
</context>
<context>
    <name>LastFmLoginDialog</name>
    <message>
        <source>Log in to %1</source>
        <translation>Ввійти на %1</translation>
    </message>
    <message>
        <source>&amp;Username:</source>
        <translation>&amp;Ім’я користувача:</translation>
    </message>
    <message>
        <source>&amp;Password:</source>
        <translation>&amp;Пароль:</translation>
    </message>
    <message>
        <source>Signup for a %1 account</source>
        <translation>Зареєструвати %1 аккаунт</translation>
    </message>
    <message>
        <source>Forgot your &lt;a href=&apos;%1&apos;&gt;username&lt;/a&gt; or &lt;a href=&apos;%2&apos;&gt;password&lt;/a&gt;?</source>
        <translation>Забули ваше &lt;a href=&apos;%1&apos;&gt;ім’я користувача&lt;/a&gt; чи &lt;a href=&apos;%2&apos;&gt;пароль&lt;/a&gt;?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Відміна</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Назад</translation>
    </message>
    <message>
        <source>Go to the previous view</source>
        <translation>Повернутись до попереднього вигляду</translation>
    </message>
    <message>
        <source>&amp;Info</source>
        <translation>&amp;Інформація</translation>
    </message>
    <message>
        <source>Show information about the current track</source>
        <translation>Показати інформацію про поточну композицію</translation>
    </message>
    <message>
        <source>P&amp;revious</source>
        <translation>По&amp;передній</translation>
    </message>
    <message>
        <source>Go back to the previous track</source>
        <translation>Повернутись до попереднього треку</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation>&amp;Наступний</translation>
    </message>
    <message>
        <source>Skip to the next track</source>
        <translation>Перейти до наступного треку</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Відтворити</translation>
    </message>
    <message>
        <source>Start playback</source>
        <translation>Почати відтворення.</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;На весь екран</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>На весь екран</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Видалити</translation>
    </message>
    <message>
        <source>Remove the selected tracks from the playlist</source>
        <translation>Видалити позначені треки з плейлиста</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Перемістити &amp;Вгору</translation>
    </message>
    <message>
        <source>Move up the selected tracks in the playlist</source>
        <translation>Перемістити вгору обрані треки в плейлисті</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Перемістити &amp;Вниз</translation>
    </message>
    <message>
        <source>Move down the selected tracks in the playlist</source>
        <translation>Перемістити вниз обрані треки в плейлисті</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Вийти</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Щасливо</translation>
    </message>
    <message>
        <source>&amp;Change collection folder...</source>
        <translation>&amp;Змінити теку музичної колекції...</translation>
    </message>
    <message>
        <source>Choose a different music collection folder</source>
        <translation>Виберіть іншу теку музичної колекції</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>&amp;Веб-сайт</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 у веб-мережі</translation>
    </message>
    <message>
        <source>Make a &amp;donation</source>
        <translation>Підтрима&amp;йте проект</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Будь ласка, підтримайте подальший розвиток %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Про програму</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Інформація щодо %1</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>&amp;Очистити</translation>
    </message>
    <message>
        <source>Remove all tracks from the playlist</source>
        <translation>Очистити плейлист</translation>
    </message>
    <message>
        <source>&amp;Shuffle</source>
        <translation>&amp;Змішати</translation>
    </message>
    <message>
        <source>Random playlist mode</source>
        <translation>Грати у випадковому порядку</translation>
    </message>
    <message>
        <source>&amp;Repeat</source>
        <translation>&amp;Повторити</translation>
    </message>
    <message>
        <source>Play first song again after all songs are played</source>
        <translation>Відтворювати першу композицію знову після завершення списку</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Вимкнути звук</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;Програма</translation>
    </message>
    <message>
        <source>&amp;Playback</source>
        <translation>&amp;Відтворення</translation>
    </message>
    <message>
        <source>Play&amp;list</source>
        <translation>Плей&amp;лист</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Вигляд</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Допомога</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Натисніть %1 для підняття гучності, %2 для її зниження</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Відкриваю %1</translation>
    </message>
    <message>
        <source>Updating collection...</source>
        <translation>Оновлення колекції...</translation>
    </message>
    <message>
        <source>Updating collection - %1%</source>
        <translation>Оновлення колекції - %1%</translation>
    </message>
    <message>
        <source>Collection updated</source>
        <translation>Колекцію оновлено</translation>
    </message>
    <message>
        <source>Fatal error: %1</source>
        <translation>Критична помилка: %1</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Помилка: %1</translation>
    </message>
    <message>
        <source>Leave &amp;Full Screen</source>
        <translation>Вийти з &amp;повноекранного режиму</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Залишилось часу: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Гучність %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Звук вимкнено</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Звук увімкнено</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Отримати повнофункціональну версію</translation>
    </message>
    <message>
        <source>%1 version %2 is now available.</source>
        <translation>%1 версія %2 доступна.</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Нагадати мені пізніше</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Оновлення</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Вікно</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>&amp;Звернути</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Закрити</translation>
    </message>
    <message>
        <source>Buy %1...</source>
        <translation>Придбати %1...</translation>
    </message>
    <message>
        <source>&amp;Stop After This Track</source>
        <translation>&amp;Зупинити після цього треку</translation>
    </message>
    <message>
        <source>&amp;Scrobbling</source>
        <translation>&amp;Скроблінг</translation>
    </message>
    <message>
        <source>Send played tracks titles to %1</source>
        <translation>Надіслати треки, які грали до %1</translation>
    </message>
    <message>
        <source>&amp;Log Out from %1</source>
        <translation>&amp;Вийти з %1</translation>
    </message>
    <message>
        <source>&amp;Report an Issue...</source>
        <translation>По&amp;відомити про помилку</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Пошук</translation>
    </message>
    <message>
        <source>%1 finished scanning your music collection</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Love %1? Rate it!</source>
        <translation>&amp;Подобається %1? Оцініть !</translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>Drop items here</source>
        <translation>Перетягнути пункти сюди</translation>
    </message>
    <message>
        <source>Playlist finished</source>
        <translation>Плейлист завершено</translation>
    </message>
    <message>
        <source>This is just the demo version of %1.</source>
        <translation>Це всього лише демо-версія %1.</translation>
    </message>
    <message>
        <source>It allows you to play a few tracks so you can test the application and see if it works for you.</source>
        <translation>Це дозволяє відтворювати кілька треків, отже ви можете протестувати програму і побачити, чи вона вам підходить.</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Продовжити</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Отримати повну версію</translation>
    </message>
</context>
<context>
    <name>MessageWidget</name>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>Доступна нова версія %1!</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>%1 %2 доступна. Ви маєте %3.</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>Ви бажаєте завантажити зараз?</translation>
    </message>
    <message>
        <source>Skip This Version</source>
        <translation>Пропустити цю версію</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>Нагадати пізніше</translation>
    </message>
    <message>
        <source>Install Update</source>
        <translation>Встановити оновлення</translation>
    </message>
</context>
<context>
    <name>PasteLineEdit</name>
    <message>
        <source>Paste</source>
        <translation>Вставити</translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <source>This demo is limited to only %1 tracks in the playlist.</source>
        <translation>Демо обмежене до %1 треків в плейлісті.</translation>
    </message>
</context>
<context>
    <name>PlaylistView</name>
    <message>
        <source>Playlist is empty</source>
        <translation>Плейлист порожній</translation>
    </message>
    <message>
        <source>%1 tracks - Total length is %2</source>
        <translation>%1 треків - Загальний час звучання %2</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Пошук</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Your search had no results.</source>
        <translation>Нічого не знайдено</translation>
    </message>
</context>
<context>
    <name>TrackListView</name>
    <message>
        <source>Tracks</source>
        <translation>Треки</translation>
    </message>
</context>
</TS>